/* Hey EMACS -*- linux-c -*- */
/* $Id: typesxx.h 3962 2007-10-27 19:11:58Z roms $ */

/*  libtifiles - file format library, a part of the TiLP project
 *  Copyright (C) 1999-2005  Romain Lievin
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __TIFILES_DEFSXX__
#define __TIFILES_DEFSXX__

#include "types73.h"
#include "types82.h"
#include "types83.h"
#include "types83p.h"
#include "types84p.h"
#include "types85.h"
#include "types86.h"
#include "types89.h"
#include "types89t.h"
#include "types92.h"
#include "types92p.h"
#include "typesv2.h"
#include "typesnsp.h"

#endif
